summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/kplayerslideraction.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/kplayerslideraction.cpp')
-rw-r--r--umbrello/umbrello/kplayerslideraction.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/umbrello/umbrello/kplayerslideraction.cpp b/umbrello/umbrello/kplayerslideraction.cpp
index 05ce0100..e7614daf 100644
--- a/umbrello/umbrello/kplayerslideraction.cpp
+++ b/umbrello/umbrello/kplayerslideraction.cpp
@@ -33,11 +33,11 @@ void KPlayerPopupFrame::keyPressEvent (TQKeyEvent* ev)
{
switch ( ev -> key() )
{
- case Qt::Key_Alt:
- case Qt::Key_Tab:
- case Qt::Key_Escape:
- case Qt::Key_Return:
- case Qt::Key_Enter:
+ case TQt::Key_Alt:
+ case TQt::Key_Tab:
+ case TQt::Key_Escape:
+ case TQt::Key_Return:
+ case TQt::Key_Enter:
close();
}
}
@@ -50,7 +50,7 @@ void KPlayerPopupFrame::keyPressEvent (TQKeyEvent* ev)
void KPlayerPopupFrame::mousePressEvent (TQMouseEvent* ev)
{
TQFrame::mousePressEvent (ev);
-//if ( ! rect().contains (ev -> pos()) )
+//if ( ! rect().tqcontains (ev -> pos()) )
// m_outside_mouse_press = true;
}
@@ -60,21 +60,21 @@ void KPlayerPopupFrame::mouseReleaseEvent (TQMouseEvent* ev)
if ( m_outside_mouse_press )
{
m_outside_mouse_press = false;
- if ( ! rect().contains (ev -> pos()) )
+ if ( ! rect().tqcontains (ev -> pos()) )
close();
}
}*/
KPlayerPopupSliderAction::KPlayerPopupSliderAction (const TQString& text,
const TQString& pix, const KShortcut& shortcut, const TQObject* receiver,
- const char* slot, TQObject* parent, const char* name)
- : KAction (text, pix, shortcut, parent, name)
+ const char* slot, TQObject* tqparent, const char* name)
+ : KAction (text, pix, shortcut, tqparent, name)
{
m_frame = new KPlayerPopupFrame;
m_frame -> setFrameStyle (TQFrame::PopupPanel | TQFrame::Raised);
m_frame -> setLineWidth (2);
m_slider = new KPlayerSlider (Qt::Vertical, m_frame);
- m_frame -> resize (36, m_slider -> sizeHint().height() + 4);
+ m_frame -> resize (36, m_slider -> tqsizeHint().height() + 4);
m_slider -> setGeometry (m_frame -> contentsRect());
//CHANGED kdDebug() << "Popup slider size " << m_slider -> width() << "x" << m_slider -> height() << "\n";
connect (m_slider, TQT_SIGNAL (changed (int)), receiver, slot);
@@ -158,9 +158,9 @@ void KPlayerPopupSliderAction::slotActivated (void)
}
KPlayerSliderAction::KPlayerSliderAction (const TQString& text, const KShortcut& cut,
- const TQObject* receiver, const char* slot, KActionCollection* parent, const char* name)
- : KWidgetAction (new KPlayerSlider (Qt::Horizontal, 0, name), text, cut, receiver, slot, parent, name)
- //: KAction (text, 0, parent, name)
+ const TQObject* receiver, const char* slot, KActionCollection* tqparent, const char* name)
+ : KWidgetAction (new KPlayerSlider (Qt::Horizontal, 0, name), text, cut, receiver, slot, tqparent, name)
+ //: KAction (text, 0, tqparent, name)
{
setAutoSized (true);
connect (slider(), TQT_SIGNAL (changed (int)), receiver, slot);
@@ -187,7 +187,7 @@ int KPlayerSliderAction::plug (TQWidget* widget, int index)
return result;
KToolBar* toolbar = (KToolBar*) widget;
//int id = getToolButtonID();
- //kdDebug() << "Orientation: " << toolbar -> orientation() << "\n";
+ //kdDebug() << "Qt::Orientation: " << toolbar -> orientation() << "\n";
//m_slider -> reparent (toolbar, TQPoint());
//toolbar -> insertWidget (id, 0, m_slider, index);
//toolbar -> setItemAutoSized (id, true);
@@ -199,10 +199,10 @@ int KPlayerSliderAction::plug (TQWidget* widget, int index)
//addContainer (toolbar, id);
//setupToolbar (toolbar -> orientation(), toolbar);
orientationChanged (toolbar -> orientation());
- connect (toolbar, TQT_SIGNAL (orientationChanged (Orientation)), this, TQT_SLOT (orientationChanged (Orientation)));
+ connect (toolbar, TQT_SIGNAL (orientationChanged (Qt::Orientation)), this, TQT_SLOT (orientationChanged (Qt::Orientation)));
//connect (toolbar, TQT_SIGNAL (destroyed()), this, TQT_SLOT (toolbarDestroyed()));
- //if ( parentCollection() )
- // parentCollection() -> connectHighlight (toolbar, this);
+ //if ( tqparentCollection() )
+ // tqparentCollection() -> connectHighlight (toolbar, this);
//return containerCount() - 1;
return result;
}
@@ -213,10 +213,10 @@ void KPlayerSliderAction::unplug (TQWidget* widget)
//Q_ASSERT (isPlugged());
//Q_ASSERT (widget -> inherits ("KToolBar"));
KWidgetAction::unplug (widget);
- if ( ! slider() || ! isPlugged() || widget != slider() -> parent() )
+ if ( ! slider() || ! isPlugged() || TQT_BASE_OBJECT(widget) != TQT_BASE_OBJECT(slider() -> tqparent()) )
return;
//KToolBar* toolbar = (KToolBar*) widget;
- disconnect (widget, TQT_SIGNAL (orientationChanged (Orientation)), this, TQT_SLOT (orientationChanged (Orientation)));
+ disconnect (widget, TQT_SIGNAL (orientationChanged (Qt::Orientation)), this, TQT_SLOT (orientationChanged (Qt::Orientation)));
//disconnect (toolbar, TQT_SIGNAL (destroyed()), this, TQT_SLOT (toolbarDestroyed()));
//m_slider -> reparent (0, TQPoint());
/*int index = findContainer (toolbar);
@@ -226,7 +226,7 @@ void KPlayerSliderAction::unplug (TQWidget* widget)
removeContainer (index);*/
}
-/*void KPlayerSliderAction::setupToolbar (Orientation orientation, KToolBar* toolbar)
+/*void KPlayerSliderAction::setupToolbar (Qt::Orientation orientation, KToolBar* toolbar)
{
if ( orientation == Qt::Horizontal )
{
@@ -264,9 +264,9 @@ void KPlayerSliderAction::orientationChanged (Qt::Orientation orientation)
m_slider -> reparent (0, TQPoint());
}*/
-KPlayerSlider::KPlayerSlider (Qt::Orientation orientation, TQWidget* parent, const char* name)
-//CHANGED : TQSlider (orientation, parent, name)
- : TQSlider (300, 2200, 400, 1000, orientation, parent, name)
+KPlayerSlider::KPlayerSlider (Qt::Orientation orientation, TQWidget* tqparent, const char* name)
+//CHANGED : TQSlider (orientation, tqparent, name)
+ : TQSlider (300, 2200, 400, 1000, orientation, tqparent, name)
{
m_changing_orientation = false;
setTickmarks (TQSlider::Both);
@@ -278,9 +278,9 @@ KPlayerSlider::~KPlayerSlider()
//CHANGED kdDebug() << "KPlayerSlider destroyed\n";
}
-TQSize KPlayerSlider::sizeHint() const
+TQSize KPlayerSlider::tqsizeHint() const
{
- TQSize hint = TQSlider::sizeHint();
+ TQSize hint = TQSlider::tqsizeHint();
//CHANGED int length = kPlayerSettings() -> preferredSliderLength();
int length = 200;
if ( orientation() == Qt::Horizontal )
@@ -296,10 +296,10 @@ TQSize KPlayerSlider::sizeHint() const
return hint;
}
-TQSize KPlayerSlider::minimumSizeHint() const
+TQSize KPlayerSlider::tqminimumSizeHint() const
{
//kdDebug() << "KPlayerSlider minimum size hint\n";
- TQSize hint = TQSlider::minimumSizeHint();
+ TQSize hint = TQSlider::tqminimumSizeHint();
//CHANGED int length = kPlayerSettings() -> minimumSliderLength();
int length = 200;
if ( orientation() == Qt::Horizontal )